"""
__init__.py : pylint_patcher top level
"""
from ._version import __version__

PATCHFILENAME = ".pylint-disable.patch"


